@@ -48,16 +48,6 @@ class LocalModel:
                 self.model = file
 
 
-# def _url_callback(url: str) -> Union[str, None]:
-#     """Checks url is valid"""
-#     if url == "latest":
-#         return url
-#     if validators.url(url):
-#         return url
-#     else:
-#         raise typer.BadParameter(f"Please check {url} is a valid url")
-
-
 def ensure_model_dir(model_dir_path: Union[Path, None] = None) -> Path:
     """Checks for a local model dir and creates one if not found"""
     if not model_dir_path:
@@ -171,7 +161,6 @@ def create_metrics_tables(model_info: ModelInfo) -> List[Table]:
         for result in model["results"]:
             for metric in result["metrics"]:
                 metrics.append(metric)
-    tables = []
     for metric in metrics:
         table = Table()
         for name in metric.keys():
@@ -182,8 +171,7 @@ def create_metrics_tables(model_info: ModelInfo) -> List[Table]:
         for item in metric_values
     ]
     table.add_row(*list(map(str, rounded_metric_values)))
-    tables.append(table)
-    return tables
+    return [table]
 
 
 if __name__ == "__main__":  # pragma: no cover
